@@ -1,8 +1,11 @@
 __all__ = ['utils', 'types', 'meta', 'lang', 'tree_mini', 'parsing', 'magics',
-           'lnsetup', 'display', 'combinators', 'auto']
+           'lnsetup', 'display', 'combinators', 'auto', 'console']
 
-__version_info__ = (0, 7, 1)
+__version_info__ = (0, 8, 0)
 __release__ = True
 __version__ = ".".join(str(i) for i in __version_info__)
 if not __release__:
     __version__ = __version__ + "a1"
+
+from .meta import te, tp, unify
+from .parsing import error_manager as errors
