@@ -1112,8 +1112,6 @@ class TreeLayout(object):
     def box_constituent(self, path, stroke="none", rounding=8,
                         stroke_width=1, fill="gray", fill_opacity=0.15):
         (x, y, width, height) = self.subtree_bounds(path)
-        print((x, y, width, height))
-        print(f"stroke_width: {stroke_width}")
         rect = svgwrite.shapes.Rect(insert=(perc(x), em(y, self.options)),
                                     size=(perc(width), em(height, self.options)),
                                     stroke=stroke,
@@ -1122,7 +1120,6 @@ class TreeLayout(object):
                                     rx=rounding,
                                     ry=rounding,
                                     stroke_width=stroke_width)
-        # self.extra_y = max(self.extra_y, (y + height) + 0.5 - (self.em_height() - self.extra_y))
         self.annotations.append(rect)
         return self
 
